Collection 收藏夹类
===================

..  autoclass:: zhihu.collection.Collection
    :members:
    :special-members: __init__

..  autoclass:: zhihu.collection.CollectActivity
    :members:
    :special-members: __init__

..  autoclass:: zhihu.acttype.CollectActType
    :members:
